========
Créditos
========

Desenvolvedor
-------------

PySIGEP foi desenvolvido originalmente por:

* Michell Stuttgart (https://github.com/mstuttgart)

Contribuidores
--------------

Agradecimentos aos seguintes contribuidores pelo esforço de fazer a PySIGEP
melhor:

* [Alessandro Martini](https://github.com/martini97)
* [Danimar Ribeiro](https://github.com/danimaribeiro)
* [Michel Sabchuk](https://github.com/michelts)